@@ -17,16 +17,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef FIRMWARE_05_50_H
-#define FIRMWARE_05_50_H
+#ifndef FIRMWARE_04_00_H
+#define FIRMWARE_04_00_H
 
 G_BEGIN_DECLS
 
-gboolean fritzbox_login_05_50(struct profile *profile);
-gboolean fritzbox_get_settings_05_50(struct profile *profile);
-void fritzbox_journal_cb(SoupSession *session, SoupMessage *msg, gpointer user_data);
-gboolean fritzbox_load_journal_05_50(struct profile *profile, gchar **data_ptr);
-gboolean fritzbox_clear_journal_05_50(struct profile *profile);
+gboolean fritzbox_present_04_00(struct router_info *router_info);
+gboolean fritzbox_login_04_00(struct profile *profile);
+gboolean fritzbox_dial_number_04_00(struct profile *profile, gint port, const gchar *number);
+gboolean fritzbox_hangup_04_00(struct profile *profile, gint port, const gchar *number);
 
 G_END_DECLS
 
