@@ -32,6 +32,7 @@
 #include <libroutermanager/profile.h>
 #include <libroutermanager/lookup.h>
 #include <libroutermanager/gstring.h>
+#include <libroutermanager/settings.h>
 
 #include <roger/main.h>
 #include <roger/application.h>
@@ -60,24 +61,17 @@ static gchar **selected_incoming_numbers = NULL;
 static void notify_accept_clicked_cb(GtkWidget *notify, gpointer user_data)
 {
 	struct connection *connection = user_data;
-	struct contact contact_s;
-	struct contact *contact = &contact_s;
-
-	/** Ask for contact information */
-	memset(contact, 0, sizeof(struct contact));
-	contact_s.number = connection->remote_number;
-	emit_contact_process(contact);
+	struct contact *contact;
 
 	g_assert(connection != NULL);
 
+	/** Ask for contact information */
+	contact = contact_find_by_number(connection->remote_number);
+
 	gtk_widget_destroy(connection->notification);
 	connection->notification = NULL;
 
-	app_show_phone_window(contact);
-
-	phone_pickup(connection->priv ? connection->priv : active_capi_connection);
-
-	phone_add_connection(connection->priv ? connection->priv : active_capi_connection);
+	app_show_phone_window(contact, connection);
 }
 
 /**
@@ -168,8 +162,7 @@ void notification_gtk_connection_notify_cb(AppObject *obj, struct connection *co
 	GtkWidget *contact_street_label;
 	GtkWidget *city_label;
 	GtkWidget *contact_city_label;
-	struct contact contact_s;
-	struct contact *contact = &contact_s;
+	struct contact *contact;
 	gchar **numbers = NULL;
 	gchar *tmp;
 	gint count;
@@ -200,18 +193,27 @@ void notification_gtk_connection_notify_cb(AppObject *obj, struct connection *co
 	}
 
 	if (!found && connection->local_number[0] != '0') {
-		g_debug("type: %d, number '%s' not found", connection->type, call_scramble_number(connection->local_number));
-
+		gchar *scramble_local = call_scramble_number(connection->local_number);
 		gchar *tmp = call_full_number(connection->local_number, FALSE);
+		gchar *scramble_tmp = call_scramble_number(tmp);
+
+		g_debug("type: %d, number '%s' not found", connection->type, scramble_local);
 
 		/* Match numbers against local number and check if we should show a notification */
 		for (count = 0; count < g_strv_length(numbers); count++) {
-			g_debug("type: %d, number '%s'/'%s' <-> '%s'", connection->type, call_scramble_number(connection->local_number), call_scramble_number(tmp), call_scramble_number(numbers[count]));
+			gchar *scramble_number = call_scramble_number(numbers[count]);
+
+			g_debug("type: %d, number '%s'/'%s' <-> '%s'", connection->type, scramble_local, scramble_tmp, scramble_number);
+			g_free(scramble_number);
+
 			if (!strcmp(tmp, numbers[count])) {
 				found = TRUE;
 				break;
 			}
 		}
+
+		g_free(scramble_local);
+		g_free(scramble_tmp);
 		g_free(tmp);
 	}
 
@@ -235,9 +237,7 @@ void notification_gtk_connection_notify_cb(AppObject *obj, struct connection *co
 	}
 
 	/** Ask for contact information */
-	memset(contact, 0, sizeof(struct contact));
-	contact_s.number = connection->remote_number;
-	emit_contact_process(contact);
+	contact = contact_find_by_number(connection->remote_number);
 
 	notify = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
@@ -423,7 +423,7 @@ void impl_activate(PeasActivatable *plugin)
 {
 	RouterManagerNotificationGtkPlugin *notify_plugin = ROUTERMANAGER_NOTIFICATION_GTK_PLUGIN(plugin);
 
-	notification_gtk_settings = g_settings_new("org.tabos.roger.plugins.gtknotify");
+	notification_gtk_settings = rm_settings_plugin_new("org.tabos.roger.plugins.gtknotify", "gtknotify");
 
 	gchar **incoming_numbers = g_settings_get_strv(notification_gtk_settings, "incoming-numbers");
 	gchar **outgoing_numbers = g_settings_get_strv(notification_gtk_settings, "outgoing-numbers");
