@@ -24,11 +24,9 @@
 GtkWidget *ui_label_new(gchar *text)
 {
 	GtkWidget *label;
-	GdkRGBA col;
 
 	label = gtk_label_new(text);
-	gdk_rgba_parse(&col, "#808080");
-	gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &col);
+	gtk_widget_set_sensitive(label, FALSE);
 	gtk_widget_set_halign(label, GTK_ALIGN_END);
 
 	return label;
@@ -44,7 +42,7 @@ void gtk_widget_set_margin(GtkWidget *widget, gint x1, gint y1, gint x2, gint y2
 	gtk_widget_set_margin_top(widget, y1);
 	gtk_widget_set_margin_bottom(widget, y2);
 
-#if GTK_CHECK_VERSION(3, 12, 0)
+#if GTK_CHECK_VERSION(3,12,0)
 	gtk_widget_set_margin_start(widget, x1);
 	gtk_widget_set_margin_end(widget, x2);
 #else
@@ -52,3 +50,23 @@ void gtk_widget_set_margin(GtkWidget *widget, gint x1, gint y1, gint x2, gint y2
 	gtk_widget_set_margin_right(widget, x2);
 #endif
 }
+
+void ui_set_suggested_style(GtkWidget *widget)
+{
+#ifdef GTK_STYLE_CLASS_SUGGESTED_ACTION
+	gtk_style_context_add_class(gtk_widget_get_style_context(widget), GTK_STYLE_CLASS_SUGGESTED_ACTION);
+#endif
+}
+
+void ui_set_destructive_style(GtkWidget *widget)
+{
+#ifdef GTK_STYLE_CLASS_DESTRUCTIVE_ACTION
+	gtk_style_context_add_class(gtk_widget_get_style_context(widget), GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
+#endif
+}
+void ui_set_button_style(GtkWidget *widget)
+{
+#ifdef GTK_STYLE_CLASS_BUTTON_ACTION
+	gtk_style_context_add_class(gtk_widget_get_style_context(widget), GTK_STYLE_CLASS_BUTTON_ACTION);
+#endif
+}
